export enum DrivingSide {
  LEFT = "left",
  RIGHT = "right",
}

export type OSMRLocation = number[]

export interface OSMRWaypoint {
  location: OSMRLocation
  distance: number
  hint: string
  name: string
}

export interface OSMRIntersection {
  location: OSMRLocation
  bearings: number[]
  entry: boolean[]
  in?: number
  out?: number
  classes: string[]
}

export interface OSMRManeuver {
  type: string
  location: OSMRLocation
  bearing_before: number
  bearing_after: number
}

export interface OSMRLegStep {
  distance: number
  duration: number
  weight: number
  driving_side: DrivingSide
  intersections: OSMRIntersection[]
  ref: string
  name: string
  mode: string
  maneuver: OSMRManeuver
  geometry: string
}

export interface OSMRLeg {
  distance: number
  steps: OSMRLegStep[]
  duration: number
  weight: number
  summary: string
}

export interface OSMRRoute {
  distance: number
  weight_name: SVGStringList
  legs: OSMRLeg[]
  duration: number
  weight: number
  geometry: string
}

export interface OSMRTrain {
  waypoints: OSMRWaypoint[]
  routes: OSMRRoute[]
}

export interface OSMRError {
  code: string
  message: string
}

export type OSMRResponse = OSMRTrain & OSMRError
